==> at_persistence_secondary_server-3.0.9.tar.gz: test/prod_issue.dart <==
import 'dart:io';
import 'dart:typed_data';

import 'package:at_persistence_secondary_server/at_persistence_secondary_server.dart';
import 'package:at_utils/at_utils.dart';
import 'package:hive/hive.dart';

void main() async {
  final atSign = '@murali';
  var _boxName= AtUtils.getShaForAtSign(atSign);
  print('$_boxName');
  final storagePath = '/home/murali/work/2021/@/compaction/storage/commitLog';
  Hive.init(storagePath);
  if (!Hive.isAdapterRegistered(AtDataAdapter().typeId)) {
    Hive.registerAdapter(AtDataAdapter());
  }
  if (!Hive.isAdapterRegistered(AtMetaDataAdapter().typeId)) {
    Hive.registerAdapter(AtMetaDataAdapter());
  }
  if (!Hive.isAdapterRegistered(CommitEntryAdapter().typeId)) {
    Hive.registerAdapter(CommitEntryAdapter());
  }
  if (!Hive.isAdapterRegistered(CommitOpAdapter().typeId)) {
    Hive.registerAdapter(CommitOpAdapter());
  }

//  final secretString = File('$storagePath/$_boxName.hash').readAsStringSync();
//  final secret = Uint8List.fromList(secretString.codeUnits);
  try {
//    final box = await Hive.openBox('$_boxName', encryptionCipher: HiveAesCipher(secret));
    final box = await Hive.openBox('commit_log_$_boxName');
    print(box.isOpen);
    print(box.keys.length);
//    await box.put('111','hello111');
//    await box.put('222','hello222');
//  print(box.get('111'));
//    print(box.get('222'));
//    for (int i=150;i<172;i++) {
//      print(box.getAt(i));
//    }
    var count=0;
//    box.keys.forEach((element) {
//      final entry = box.get(element);
//      print(entry);
//      });
//    print('delete count: $count');
  } on HiveError catch(err,trace) {
      print(err.message);
      print(trace);
  }


}

==> at_persistence_secondary_server-3.0.20.tar.gz: test/prod_issue.dart <==
import 'dart:io';
import 'dart:typed_data';

import 'package:at_persistence_secondary_server/at_persistence_secondary_server.dart';
import 'package:at_utils/at_utils.dart';
import 'package:hive/hive.dart';

void main() async {
  final atSign = '@confidentialnerdcore';
  var _boxName = AtUtils.getShaForAtSign(atSign);
  print('$_boxName');
  final storagePath =
      '/home/murali/work/2021/@/prod_hive_issue/corrupted/storage/hive';
  Hive.init(storagePath);
  if (!Hive.isAdapterRegistered(AtDataAdapter().typeId)) {
    Hive.registerAdapter(AtDataAdapter());
  }
  if (!Hive.isAdapterRegistered(AtMetaDataAdapter().typeId)) {
    Hive.registerAdapter(AtMetaDataAdapter());
  }
  if (!Hive.isAdapterRegistered(CommitEntryAdapter().typeId)) {
    Hive.registerAdapter(CommitEntryAdapter());
  }
  if (!Hive.isAdapterRegistered(CommitOpAdapter().typeId)) {
    Hive.registerAdapter(CommitOpAdapter());
  }

  final secretString = File('$storagePath/$_boxName.hash').readAsStringSync();
  final secret = Uint8List.fromList(secretString.codeUnits);
  try {
    final box = await Hive.openBox('$_boxName',
        encryptionCipher: HiveAesCipher(secret));
//    final box = await Hive.openBox('commit_log_$_boxName');
    print(box.isOpen);
    print(box.keys.length);
//    await box.put('111','hello111');
//    await box.put('222','hello222');
//  print(box.get('111'));
//    print(box.get('222'));
//    for (int i=150;i<172;i++) {
//      print(box.getAt(i));
//    }
//    var count=0;
//    box.keys.forEach((element) {
//      final entry = box.get(element);
//      print(entry);
//      });
//    print('delete count: $count');
  } on HiveError catch (err, trace) {
    print(err.message);
    print(trace);
  }
}
